@@ -3,5 +3,5 @@ from tracktime.report import Report
 from tracktime.synchronisers.base import Synchroniser
 from tracktime.time_entry import TimeEntry
 
-__all__ = ('EntryList', 'Report', 'Synchroniser', 'TimeEntry')
-__version__ = '0.9.13'
+__all__ = ("EntryList", "Report", "Synchroniser", "TimeEntry")
+__version__ = "0.9.14"
